================
Python resources
================

Python is an object-oriented programming language that is widely used in the software industry. A number of resources are available to help you learn more about the Python programming language.

Python websites
---------------

The official Python website `https://www.python.org/ <https://www.python.org/>`_ contains a wealth of information on the Python programming language and the Python community. For new Python programmers the website contains links to:

- General descriptions of the Python language.
- Comparisons between Python and other programming languages.
- An introduction to Python.
- Introductory tutorials.
    
The website also contains a reference library of Python functions to which you will need to refer.

Python books
------------

- Altom, Tim, Programming With Python, Prima Publishing, ISBN: 0761523340.
- Beazley, David, Python Essential Reference (2nd Edition), New Riders Publishing, ISBN: 0735710910.
- Brown, Martin, Python: The Complete Reference, McGraw-Hill, ISBN: 07212718X.
- Brown, Martin, Python Annotated Archives, McGraw-Hill, ISBN: 072121041.
- Chun, Wesley J., Core Python Programming, Prentice Hall, ISBN: 130260363.
- Deitel, Harvey M., Python: How to Program, Prentice Hall, ISBN: 130923613.
- Gauld, Alan, Learn To Program Using Python, Addison-Wesley, ISBN: 201709384.
- Harms, Daryl D., and Kenneth McDonald, Quick Python Book, Manning Publications Company, ISBN: 884777740.
- Lie Hetland, Magnus, Practical Python, APress, ISBN: 1590590066.
- Lutz, Mark, Programming Python, O'Reilly & Associates, ISBN: 1565921976.
- Lutz, Mark, and David Ascher, Learning Python, Second Edition, O'Reilly & Associates, ISBN: 0596002815.
- Lutz, Mark, and Gigi Estabrook, Python: Pocket Reference, O'Reilly & Associates, ISBN: 1565925009.
- Martelli, Alex, Python in a Nutshell, O'Reilly & Associates, ISBN: 0596001886.
- Martelli, Alex, and David Ascher, Python Cookbook, O'Reilly & Associates, ISBN: 0596001673.
- Van Laningham, Ivan, Sams Teach Yourself Python in 24 Hours, Sams Publishing, ISBN: 0672317354.
    
The books Python Essential Reference and Learning Python are recommended reading.

Python newsgroups
-----------------

Discussions of Python programming can be found at:

- comp.lang.python
- comp.lang.python.announce
    